[Zope3-checkins] CVS: Zope3/src/zope/app/component/tests - test_servicemanagercontainer.py:1.3

R. David Murray bitz@bitdance.com
Fri, 27 Dec 2002 11:00:14 -0500


Update of /cvs-repository/Zope3/src/zope/app/component/tests
In directory cvs.zope.org:/tmp/cvs-serv20116/zope/app/component/tests

Modified Files:
	test_servicemanagercontainer.py 
Log Message:
Rename _Test__new to the (now) standard 'makeTestObject' in a couple of
unit tests.


=== Zope3/src/zope/app/component/tests/test_servicemanagercontainer.py 1.2 => 1.3 ===
--- Zope3/src/zope/app/component/tests/test_servicemanagercontainer.py:1.2	Wed Dec 25 09:12:46 2002
+++ Zope3/src/zope/app/component/tests/test_servicemanagercontainer.py	Fri Dec 27 10:59:43 2002
@@ -51,21 +51,21 @@
     given.
 
 
     Subclasses need to define a method, '_Test__new', that takes no
     arguments and that returns a new service manager
     container that has no service manager."""
 
     def testIServiceManagerContainerVerify(self):
-        verifyObject(IServiceManagerContainer, self._Test__new())
+        verifyObject(IServiceManagerContainer, self.makeTestObject())
 
     def testHas(self):
-        smc=self._Test__new()
+        smc=self.makeTestObject()
         self.failIf(smc.hasServiceManager())
         smc.setServiceManager(ServiceManager())
         self.failUnless(smc.hasServiceManager())
 
     def testGet(self):
-        smc=self._Test__new()
+        smc=self.makeTestObject()
         # since the managers are now wrapped, need to look at base object
         self.failUnless(getbaseobject(smc.queryServiceManager()) is None)
         self.assertRaises(ComponentLookupError, smc.getServiceManager)
@@ -75,13 +75,13 @@
         self.failUnless(getbaseobject(smc.queryServiceManager(self)) is sm)
 
     def testSet(self):
-        smc=self._Test__new()
+        smc=self.makeTestObject()
         self.assertRaises(Exception, smc.setServiceManager, self)
 
 
 
 class Test(BaseTestServiceManagerContainer, TestCase):
-    def _Test__new(self):
+    def makeTestObject(self):
         from zope.app.services.service \
              import ServiceManagerContainer
         return ServiceManagerContainer()
@@ -51,21 +51,21 @@
 
 
-    Subclasses need to define a method, '_Test__new', that takes no
+    Subclasses need to define a method, 'makeTestObject', that takes no
     arguments and that returns a new service manager
     container that has no service manager."""